=======
lolcatt
=======

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black

.. image:: https://img.shields.io/badge/Documentation-Github-blue
   :target: https://LokiLuciferase.github.io/lolcatt/
   :alt: Documentation

.. image:: https://github.com/LokiLuciferase/lolcatt/actions/workflows/ci.yml/badge.svg
   :target: https://github.com/LokiLuciferase/lolcatt/actions/workflows/ci.yml
   :alt: Build Status

.. image:: https://github.com/LokiLuciferase/lolcatt/raw/python-coverage-comment-action-data/badge.svg
   :target: https://github.com/LokiLuciferase/lolcatt/raw/python-coverage-comment-action-data/badge.svg
   :alt: Coverage Status


A TUI wrapper around catt_, enabling you to cast media to and control your Chromecast devices.

.. image:: https://raw.githubusercontent.com/LokiLuciferase/lolcatt/master/docs/_static/screenshot.png
   :align: center
   :alt:

* Free software: MIT license


Credits
-------

This package was created with Cookiecutter_ and the `LokiLuciferase/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/LokiLuciferase/cookiecutter
.. _`LokiLuciferase/cookiecutter-pypackage`: https://github.com/LokiLuciferase/cookiecutter-pypackage
.. _catt: https://github.com/skorokithakis/catt
